# -*- coding: utf-8 -*-
from django.db import models
from django.utils.text import slugify

from model_utils.models import TimeStampedModel


class TimeStampedLabelModel(TimeStampedModel):
    """An abstract base class model that provides label, description, active."""
    label = models.CharField(max_length=50, unique=True)
    description = models.CharField(max_length=255, blank=True)
    slug = models.SlugField(max_length=50, unique=True)
    active = models.BooleanField(default=True)

    class Meta:
        abstract = True

    def __str__(self):
        return self.label

    def save(self, **kwargs):
        self.slug = slugify(self.label)
        super(TimeStampedLabelModel, self).save(**kwargs)



from rest_framework import routers


class DefaultRouter(routers.DefaultRouter):
    """Extends `DefaultRouter` class to add a method for extending url routes from another router."""

    def extend(self, router):
        """Extend the routes with url routes of the passed in router.

        Args:
             router: SimpleRouter instance containing route definitions.
        """

        self.registry.extend(router.registry)
